@@ -27,7 +27,7 @@
 #include "frame.h"
 #include <QMap>
 #include <QStringList>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QCoreApplication>
 #include "pictureframe.h"
 
@@ -199,6 +199,7 @@ QMap<QByteArray, QByteArray> getDisplayNamesOfIds()
     { "SIGN", QT_TRANSLATE_NOOP("@default", "Signature") },
     { "SYLT", QT_TRANSLATE_NOOP("@default", "Synchronized Lyrics") },
     { "SYTC", QT_TRANSLATE_NOOP("@default", "Synchronized Tempo Codes") },
+    { "TCAT", QT_TRANSLATE_NOOP("@default", "Podcast Category") },
     { "TDAT", QT_TRANSLATE_NOOP("@default", "Date") },
     { "TDEN", QT_TRANSLATE_NOOP("@default", "Encoding Time") },
     { "TDES", QT_TRANSLATE_NOOP("@default", "Podcast Description") },
@@ -210,6 +211,7 @@ QMap<QByteArray, QByteArray> getDisplayNamesOfIds()
     { "TFLT", QT_TRANSLATE_NOOP("@default", "File Type") },
     { "TGID", QT_TRANSLATE_NOOP("@default", "Podcast Identifier") },
     { "TIME", QT_TRANSLATE_NOOP("@default", "Time") },
+    { "TKWD", QT_TRANSLATE_NOOP("@default", "Podcast Keywords") },
     { "TLEN", QT_TRANSLATE_NOOP("@default", "Length") },
     { "TOFN", QT_TRANSLATE_NOOP("@default", "Original Filename") },
     { "TOWN", QT_TRANSLATE_NOOP("@default", "File Owner") },
@@ -475,9 +477,11 @@ void Frame::setFieldListFromValue()
 int Frame::numberWithoutTotal(const QString& str, bool* ok)
 {
   int slashPos = str.indexOf(QLatin1Char('/'));
-  return slashPos == -1
-      ? str.toInt(ok)
-      : str.leftRef(slashPos).toInt(ok);
+#if QT_VERSION >= 0x060000
+  return slashPos == -1 ? str.toInt(ok) : str.left(slashPos).toInt(ok);
+#else
+  return slashPos == -1 ? str.toInt(ok) : str.leftRef(slashPos).toInt(ok);
+#endif
 }
 
 /**
@@ -968,7 +972,11 @@ namespace {
  */
 QString variantToString(const QVariant& val)
 {
+#if QT_VERSION >= 0x060000
+  if (val.typeId() == QMetaType::QByteArray) {
+#else
   if (val.type() == QVariant::ByteArray) {
+#endif
     return QString(QLatin1String("ByteArray of %1 bytes"))
         .arg(val.toByteArray().size());
   } else {
@@ -1199,11 +1207,21 @@ FrameCollection::const_iterator FrameCollection::searchByName(
     const QStringList names{it->getName(), it->getInternalName()};
     for (const QString& frameName : names) {
       QString ucFrameName(frameName.toUpper().remove(QLatin1Char('/')));
-      if (ucName == ucFrameName.leftRef(len)) {
+#if QT_VERSION >= 0x060000
+      if (ucName == ucFrameName.left(len))
+#else
+      if (ucName == ucFrameName.leftRef(len))
+#endif
+      {
         return it;
       }
       int nlPos = ucFrameName.indexOf(QLatin1Char('\n'));
-      if (nlPos > 0 && ucName == ucFrameName.midRef(nlPos + 1, len)) {
+#if QT_VERSION >= 0x060000
+      if (nlPos > 0 && ucName == ucFrameName.mid(nlPos + 1, len))
+#else
+      if (nlPos > 0 && ucName == ucFrameName.midRef(nlPos + 1, len))
+#endif
+      {
         // Description in TXXX, WXXX, COMM, PRIV matches
         return it;
       }
@@ -1656,8 +1674,9 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
     }
 
     if (lcName == QLatin1String("year")) {
-      QRegExp yearRe(QLatin1String("^\\d{4}-\\d{2}"));
-      if (yearRe.indexIn(result) == 0) {
+      QRegularExpression yearRe(QLatin1String("^\\d{4}-\\d{2}"));
+      auto match = yearRe.match(result);
+      if (match.hasMatch()) {
         result.truncate(4);
       }
     }
